@@ -33,7 +33,7 @@ class SessionHandler():
     keys = [key.name for key in inspect(obj.__class__).primary_key]
     key_values = {k: v for k, v in obj.__dict__.items() if v and k in keys}
     params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False and k not in keys}
-    instance = session.query(obj.__class__).filter_by(**key_values).first()
+    instance = session.query(obj.__class__).filter_by(**key_values)
     if instance:
       instance.update(**params)
     else:
